@@ -153,8 +153,8 @@ class TaskAssignator:
                     self.new_process,
                     simple_fargs_out)
             )
+            if not loop.is_running():
+                loop.run_until_complete(asyncio.gather(task))
         except Exception as ex:
             rprint("Error en levantar corrutina %s" % ex)
             raise ex
-        if not loop.is_running():
-            loop.run_forever()
